pub enum FreezeReason {
BenchTestReason,
}Expand description
Commitment pallet FreezeReason, merged into the runtime composite enum.
Variants
BenchTestReason
Placeholder freeze reason used exclusively for benchmarking.
Consumer pallets typically define their own bounded freeze-reason enums and may not be able to reuse this type. This pallet itself does not freeze any assets using this reason, making it suitable as a no-op placeholder for benchmarking purposes.