pub type AssetToIssue<T: Config<I>, I: 'static = ()> = StorageValue<_GeneratedPrefixForStorageAssetToIssue<T, I>, AssetOf<T, I>, ValueQuery>;Expand description
Tracks the total amount of assets that are scheduled to be issued/minted.
This value is updated whenever commitments increase a digest’s balance (reward/inflation).
Since this pallet uses lazy on-demand operations, the underlying base asset pallet may not
immediately reflect these changes. AssetToIssue provides an accounting view of the total
assets that will soon be minted and added to the system eventually.
This helps in auditing, ensuring the system knows how much asset value is pending issuance.
Storage type is [StorageValue] with value type AssetOf < T, I >.
Aliased Type
pub struct AssetToIssue<T: Config<I>, I: 'static = ()>(/* private fields */);